# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from marketplace_server_connector.models.import_order_in import ImportOrderIn  # noqa: E501

class TestImportOrderIn(unittest.TestCase):
    """ImportOrderIn unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ImportOrderIn:
        """Test ImportOrderIn
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ImportOrderIn`
        """
        model = ImportOrderIn()  # noqa: E501
        if include_optional:
            return ImportOrderIn(
                provider = 'digistore',
                buyer = marketplace_server_connector.models.import_buyer_in.ImportBuyerIn(
                    email = '', 
                    name = '', ),
                external_product_id = '',
                product_title = '',
                payment_type = 'one_time',
                occurred_at = 56,
                external_order_id = '',
                external_subscription_id = '',
                period_end = 56,
                amount = 56,
                is_test = True
            )
        else:
            return ImportOrderIn(
                provider = 'digistore',
                buyer = marketplace_server_connector.models.import_buyer_in.ImportBuyerIn(
                    email = '', 
                    name = '', ),
                external_product_id = '',
                occurred_at = 56,
        )
        """

    def testImportOrderIn(self):
        """Test ImportOrderIn"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from marketplace_server_connector.models.wrapped_response_integration_out import WrappedResponseIntegrationOut  # noqa: E501

class TestWrappedResponseIntegrationOut(unittest.TestCase):
    """WrappedResponseIntegrationOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseIntegrationOut:
        """Test WrappedResponseIntegrationOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseIntegrationOut`
        """
        model = WrappedResponseIntegrationOut()  # noqa: E501
        if include_optional:
            return WrappedResponseIntegrationOut(
                done = True,
                result = marketplace_server_connector.models.integration_out.IntegrationOut(
                    id = 56, 
                    provider = 'digistore', 
                    platform = 'web', 
                    flow = 'access', 
                    is_active = True, 
                    sync_enabled = True, 
                    credential_keys = [
                        ''
                        ], 
                    created_at = 56, 
                    updated_at = 56, )
            )
        else:
            return WrappedResponseIntegrationOut(
                result = marketplace_server_connector.models.integration_out.IntegrationOut(
                    id = 56, 
                    provider = 'digistore', 
                    platform = 'web', 
                    flow = 'access', 
                    is_active = True, 
                    sync_enabled = True, 
                    credential_keys = [
                        ''
                        ], 
                    created_at = 56, 
                    updated_at = 56, ),
        )
        """

    def testWrappedResponseIntegrationOut(self):
        """Test WrappedResponseIntegrationOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from marketplace_server_connector.models.import_orders_in import ImportOrdersIn  # noqa: E501

class TestImportOrdersIn(unittest.TestCase):
    """ImportOrdersIn unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ImportOrdersIn:
        """Test ImportOrdersIn
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ImportOrdersIn`
        """
        model = ImportOrdersIn()  # noqa: E501
        if include_optional:
            return ImportOrdersIn(
                orders = [
                    marketplace_server_connector.models.import_order_in.ImportOrderIn(
                        provider = 'digistore', 
                        buyer = marketplace_server_connector.models.import_buyer_in.ImportBuyerIn(
                            email = '', 
                            name = '', ), 
                        external_product_id = '', 
                        product_title = '', 
                        payment_type = null, 
                        occurred_at = 56, 
                        external_order_id = '', 
                        external_subscription_id = '', 
                        period_end = 56, 
                        amount = 56, 
                        is_test = True, )
                    ]
            )
        else:
            return ImportOrdersIn(
                orders = [
                    marketplace_server_connector.models.import_order_in.ImportOrderIn(
                        provider = 'digistore', 
                        buyer = marketplace_server_connector.models.import_buyer_in.ImportBuyerIn(
                            email = '', 
                            name = '', ), 
                        external_product_id = '', 
                        product_title = '', 
                        payment_type = null, 
                        occurred_at = 56, 
                        external_order_id = '', 
                        external_subscription_id = '', 
                        period_end = 56, 
                        amount = 56, 
                        is_test = True, )
                    ],
        )
        """

    def testImportOrdersIn(self):
        """Test ImportOrdersIn"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from marketplace_server_connector.models.integration_out import IntegrationOut  # noqa: E501

class TestIntegrationOut(unittest.TestCase):
    """IntegrationOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IntegrationOut:
        """Test IntegrationOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IntegrationOut`
        """
        model = IntegrationOut()  # noqa: E501
        if include_optional:
            return IntegrationOut(
                id = 56,
                provider = 'digistore',
                platform = 'web',
                flow = 'access',
                is_active = True,
                sync_enabled = True,
                credential_keys = [
                    ''
                    ],
                created_at = 56,
                updated_at = 56
            )
        else:
            return IntegrationOut(
                id = 56,
                provider = 'digistore',
                platform = 'web',
                flow = 'access',
                is_active = True,
                sync_enabled = True,
                credential_keys = [
                    ''
                    ],
                created_at = 56,
                updated_at = 56,
        )
        """

    def testIntegrationOut(self):
        """Test IntegrationOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
